@@ -82,15 +82,11 @@ impl Ident {
 }
 
 pub trait IdentExt: AsRef<str> {
-    fn is_reserved_for_es3(&self) -> bool {
+    fn is_reserved(&self) -> bool {
         [
-            "abstract",
-            "boolean",
             "break",
-            "byte",
             "case",
             "catch",
-            "char",
             "class",
             "const",
             "continue",
@@ -98,77 +94,73 @@ pub trait IdentExt: AsRef<str> {
             "default",
             "delete",
             "do",
-            "double",
             "else",
             "enum",
             "export",
             "extends",
             "false",
-            "final",
             "finally",
-            "float",
             "for",
             "function",
-            "goto",
             "if",
-            "implements",
             "import",
             "in",
             "instanceof",
-            "int",
-            "interface",
-            "long",
-            "native",
             "new",
             "null",
             "package",
-            "private",
-            "protected",
-            "public",
             "return",
-            "short",
-            "static",
             "super",
             "switch",
-            "synchronized",
             "this",
             "throw",
-            "throws",
-            "transient",
             "true",
             "try",
             "typeof",
             "var",
             "void",
-            "volatile",
             "while",
             "with",
         ]
         .contains(&self.as_ref())
     }
 
-    fn is_reserved_only_for_es3(&self) -> bool {
+    fn is_reserved_in_strict_mode(&self, is_module: bool) -> bool {
+        if is_module && self.as_ref() == "await" {
+            return true;
+        }
+        [
+            "implements",
+            "interface",
+            "let",
+            "package",
+            "private",
+            "protected",
+            "public",
+            "static",
+            "yield",
+        ]
+        .contains(&self.as_ref())
+    }
+
+    fn is_reserved_in_strict_bind(&self) -> bool {
+        ["eval", "arguments"].contains(&self.as_ref())
+    }
+
+    fn is_reserved_in_es3(&self) -> bool {
         [
             "abstract",
             "boolean",
             "byte",
             "char",
             "double",
-            "enum",
             "final",
             "float",
             "goto",
-            "implements",
             "int",
-            "interface",
             "long",
             "native",
-            "package",
-            "private",
-            "protected",
-            "public",
             "short",
-            "static",
             "synchronized",
             "throws",
             "transient",
@@ -180,3 +172,5 @@ pub trait IdentExt: AsRef<str> {
 
 impl IdentExt for JsWord {}
 impl IdentExt for Ident {}
+impl IdentExt for &'_ str {}
+impl IdentExt for String {}
